@@ -87,7 +87,7 @@ class AllInOneRepository(VersionedFileRepository):
         if not isinstance(file_or_path, str):
             file_or_path = '/'.join(file_or_path)
         if file_or_path == '':
-            return u''
+            return ''
         return urlutils.escape(osutils.safe_unicode(file_or_path))
 
     def __init__(self, _format, a_controldir):
@@ -114,7 +114,7 @@ class AllInOneRepository(VersionedFileRepository):
             # which allows access to this old info.
             self.inventory_store = get_store('inventory-store')
             self._text_store = get_store('text-store')
-        super(AllInOneRepository, self).__init__(
+        super().__init__(
             _format, a_controldir, a_controldir._control_files)
 
     def _all_possible_ids(self):
@@ -197,7 +197,7 @@ class WeaveMetaDirRepository(MetaDirVersionedFileRepository):
     """A subclass of MetaDirRepository to set weave specific policy."""
 
     def __init__(self, _format, a_controldir, control_files):
-        super(WeaveMetaDirRepository, self).__init__(
+        super().__init__(
             _format, a_controldir, control_files)
         self._serializer = _format._serializer
 
@@ -608,7 +608,7 @@ class TextVersionedFiles(VersionedFiles):
         if not self._can_write():
             raise errors.ReadOnlyError(self)
         if b'/' in key[-1]:
-            raise ValueError('bad idea to put / in %r' % (key,))
+            raise ValueError('bad idea to put / in {!r}'.format(key))
         chunks = lines
         if self._compressed:
             chunks = tuned_gzip.chunks_to_gzip(chunks)
